@@ -2,12 +2,12 @@
 import re
 
 
-def silabea(palabra):
-    return silabas(palabra).silabas
+def silabea(word):
+    return silabas(word).silabas
 
 
-def tonica(palabra):
-    return silabas(palabra).tonica
+def tonica(word):
+    return silabas(word).tonica
 
 
 def tonica_s(slbs):
@@ -35,25 +35,67 @@ class silabas:
                'ä', 'ë', 'ï', 'ö', 'ü']
 
     def __init__(self, palabra):
-        self.palabra = palabra
+        self.palabra = self.__excepciones(palabra)
         self.silabas = self.__silabea(self.palabra)
         self.tonica = tonica_s(self.silabas)
 
+    @staticmethod
+    def __excepciones(palabra):
+        uir = ['uir', 'uido', 'uida', 'uid', 'uidos', 'uidas'
+               'uimos',
+               'uiste', 'uisteis',  'uido', 'uida', 'uid'
+               'uiré', 'uirás', 'uirá', 'uiremos', 'uiréis', 'uirán',           # Quilis (2019, 185) exceptua el futuro
+               'uiría', 'uirías', 'uiría', 'uiríamos', 'uiríais', 'uirían']     # Quilis (2019, 185) exceptua el condicional
+
+        uar = ['uar', 'uado', 'uada', 'uad', 'uás', 'uados', 'uadas'
+               'uamos', 'uáis',
+               'uaba', 'uabas', 'uábamos', 'uabais', 'uaban',
+               'uaste', 'uó', 'uamos', 'uasteis', 'uaron',
+               'uaré', 'uarás', 'uará', 'uaremos', 'uaréis', 'uarán',           # Quilis (2019, 185) exceptua el futuro
+               'uaría', 'uarías', 'uaría', 'uaríamos', 'uaríais', 'uarían']     # Quilis (2019, 185) exceptua el condicional
+
+
+        excepto = ['g','c']
+
+        uoso = ['uoso', 'uosa', 'uosos', 'uosas']
+
+        #monosilabos ['ió', 'uá', 'uhá', 'ihón', ]
+
+        nombres = ['biombo', 'miasma', 'confianza', 'arrier', 'ferrovial',      # Quilis 185-186. No incluyo circuito, 
+                   'hiato', 'anual', 'acuos', 'santuario', 'cruel', 'tiara',    # que elicito /cir-cui-to/,
+                   'maniobra', 'diálogo', 'boquianch', 'diablo', 'triángulo',   # hasta que indague más en el tema
+                   'cliente', 'trienio', 'dieciocho', 'truhán', 'guion',
+                   'guión', 'Sión', 'veintiocho', 'bienio', 'prior', 'fianza',
+                   'piano', 'crianza', 'gorrión', 'jesuita', 'huida',
+                   'fortuito', 'diurno']
+        if any(palabra.endswith(x) for x in uir if len(x)+2 <= len(palabra)):
+            print(palabra)
+        if (any(x in palabra for x in nombres) or
+            any(palabra.endswith(x)  for x in nombres) or
+            any(palabra.endswith(x) for x in uir if len(x)+2 <= len(palabra))
+            or any(palabra.endswith(x) for x in uar
+                   if not palabra.endswith(f'g{x}'))):
+            palabra = re.sub('u([aeioáéó])', r'ü\1', palabra)
+            palabra = re.sub('i([aeouáéó])', r'ï\1', palabra)
+        return palabra
+
+
     def __silabea(self, letras):
         extranjeras = {'à': 'a', 'è': 'e', 'ì': 'i', 'ò': 'o', 'ù': 'u',
-                       'ã': 'a', 'ẽ': 'e', 'ĩ': 'i', 'õ': 'o', 'ũ': 'u'}
+                       'ã': 'a', 'ẽ': 'e', 'ĩ': 'i', 'õ': 'o', 'ũ': 'u',
+                       'ﬁ': 'fi', 'ﬂ': 'fl'}
         diccionario = {'b': 'be', 'c': 'ce', 'd': 'de', 'f': 'efe', 'g': 'ge',
                        'h': 'hache', 'j': 'jota', 'k': 'ka', 'l': 'ele',
                        'm': 'eme', 'n': 'ene', 'p': 'pe', 'q': 'qu',
                        'r': 'erre', 's': 'ese', 't': 'te', 'v': 'uve',
-                       'w': 'uvedoble', 'x': 'equis', 'y': 'igriega',
-                       'z': 'zeta'}
+                       'w': 'uvedoble', 'x': 'equis',
+                       'z': 'zeta', 'ph': 'pehache'}
         slbs = []
         palabra = re.sub(r'\W', '', letras)
-        if palabra.lower() in diccionario:
-            palabra = diccionario[palabra]
         palabra = ''.join([letra if letra not in extranjeras
                            else extranjeras[letra] for letra in letras])
+        if palabra.lower() in diccionario:
+            palabra = diccionario[palabra]
         slbs[:0] = palabra
         slbs = self.__une(slbs)
         slbs = self.__separa(slbs)
@@ -69,25 +111,25 @@ class silabas:
             if len(lista) == 0:
                 lista = [letra]
             elif (letra.lower() in self.vocales and
-                    lista[-1][-1].lower() in self.vocales and not
-                  any(y.lower() in hiatos for y in (lista[-1][-1], letra))):
-                ultimas = ''.join(lista).lower()
-                if (letra in debiles and (ultimas.endswith('qu') or
-                    ultimas.endswith('gü'))) or (
-                            any(y.lower() in cerradas for
-                                y in (lista[-1][-1], letra)) and not (
-                                    any(y.lower() in dieresis for y in (
-                                        lista[-1][-1], letra)))):
-                    lista[-1] = lista[-1] + letra
-                else:
-                    lista = lista + [letra]
+                  lista[-1][-1].lower() in self.vocales) and (
+                      (not any(y.lower() in hiatos
+                               for y in (lista[-1][-1], letra)) and
+                       any(y.lower() in cerradas for y in
+                           (lista[-1][-1], letra)) and
+                       not any(y.lower() in dieresis for
+                               y in (lista[-1][-1], letra))) or
+                      (letra in debiles and
+                          ''.join(lista).lower().endswith('gü'))) or (
+                                  ''.join(lista).lower().endswith('qu')):
+                lista[-1] = lista[-1] + letra
             else:
                 lista = lista + [letra]
         return lista
 
     def __separa(self, letras):
-        inseparables_onset = ['pl', 'bl', 'fl', 'cl', 'kl', 'll',
-                              'pr', 'br', 'fr', 'cr', 'kr', 'rr', 'tr', 'ch']
+        inseparables_onset = ['pl', 'bl', 'fl', 'cl', 'kl', 'gl', 'll',
+                              'pr', 'br', 'fr', 'cr', 'kr', 'gr', 'rr',
+                              'tr', 'ch']
         inseparables_coda = ['ns', 'bs']
         lista = []
         onset = ''
